
--[[ Use Addon Wide Data Table ]]--
local addonName,addonData = ...

--[[ Localise Addon Wide Data Table Sub Tables ]]--
local Translate = addonData.Translate

--[[ Make sure we have nUI tables ]]--
if not nUI_InfoPanels then nUI_InfoPanels = {}; end

--[[ Set Up nUI InfoPanel Values ]]--
nUI_INFOMODE_EAVESDROP  = 17;
nUI_INFOPANEL_EAVESDROP = "nUI_InfoPanel_Eavesdrop";

--[[ Set Up the Info Panel Table ]]--
nUI_InfoPanels[nUI_INFOPANEL_EAVESDROP ] =
{	
	enabled   = true,
	desc      = Translate["INFO_PANEL_TEXT"],		-- player friendly name/description of the panel
	label     = Translate["INFO_PANEL_LABEL"],		-- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_EAVESDROP,				-- index or position this panel appears on/in when clicking the selector button
	full_size = true,								-- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

--[[ Create the InfoPanel Plugin ]]--
local plugin    = CreateFrame( "Frame", nUI_INFOPANEL_EAVESDROP, nUI_Dashboard.Anchor );
plugin.active   = true;

--[[ Disable the Decursive Frame ]]--
disableEavesDrop = function()
	local Eavesdrop = plugin.Eavesdrop;
	local EavesDropOptions = EavesDrop.db.profile;
	if Eavesdrop.saved_parent then
		nUI_Movers:lockFrame( Eavesdrop, false, nil );
		Eavesdrop:SetParent( Eavesdrop.saved_parent );
		Eavesdrop:SetBackdropBorderColor( Eavesdrop.border_color );
		Eavesdrop:SetBackdropColor( Eavesdrop.backdrop_color );
		EavesDropOptions["LINEHEIGHT"] = Eavesdrop.oldSettings["LINEHEIGHT"];
		EavesDropOptions["LOCKED"] = Eavesdrop.oldSettings["LOCKED"];
		local b = Eavesdrop.oldSettings["BORDER"]
		EavesDropOptions["BORDER"] = { r = b.r, g = b.g, b = b.b, a = b.a };
		EavesDropOptions["NUMLINES"] = Eavesdrop.oldSettings["NUMLINES"];
		EavesDropOptions["LINEWIDTH"] = Eavesdrop.oldSettings["LINEWIDTH"];
	end
end

copyEavesDropProfile = function(src,dest)
	dest = dest or {};
	for key,data in pairs(src) do
		dest[key] = dest[key] or {};
		if ( type(data) == "table" ) then
			copyEavesDropProfile(data,dest[key]);
		else
			dest[key] = data;
		end
	end
end

--[[ Enable the Decursive Frame ]]--
enableEavesDrop = function()
	local Eavesdrop = EavesDropFrame;
	local EavesDropOptions = EavesDrop.db.profile;

	plugin.Eavesdrop = Eavesdrop;
	if not Eavesdrop.saved_parent then
		Eavesdrop.saved_parent   = Eavesdrop:GetParent();
		Eavesdrop.border_color   = Eavesdrop:GetBackdropBorderColor();
		Eavesdrop.backdrop_color = Eavesdrop:GetBackdropColor();
		Eavesdrop.oldSettings = {};
		Eavesdrop.oldSettings["LINEHEIGHT"] = EavesDropOptions["LINEHEIGHT"];
		Eavesdrop.oldSettings["LOCKED"] = EavesDropOptions["LOCKED"];
		local b = EavesDropOptions["BORDER"]
		Eavesdrop.oldSettings["BORDER"] = { r = b.r, g = b.g, b = b.b, a = b.a };
		Eavesdrop.oldSettings["NUMLINES"] = EavesDropOptions["NUMLINES"];
		Eavesdrop.oldSettings["LINEWIDTH"] = EavesDropOptions["LINEWIDTH"];

	end
	Eavesdrop:SetParent( plugin.container );
	Eavesdrop:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 10, 10 );
	Eavesdrop:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", 0, 0 );
	Eavesdrop:SetFrameStrata( plugin.container:GetFrameStrata() );
	Eavesdrop:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
	Eavesdrop:SetBackdropBorderColor( 0, 0, 0, 0 );
	Eavesdrop:SetBackdropColor( 0, 0, 0, 0 );
	
	EavesDropOptions["LINEHEIGHT"] = 12;
	EavesDropOptions["LOCKED"] = true;
	EavesDropOptions["BORDER"] = {r = 0, g = 0, b = 0, a = 0}
	EavesDrop:UpdateFrame();
	
	nUI_Movers:lockFrame( Eavesdrop, true, nil );
end

--[[ Resize the Decursive Frame ]]--
resizeEavesDrop = function()
	local Eavesdrop   = plugin.Eavesdrop;
	local EavesDropOptions = EavesDrop.db.profile;
	nUI_Movers:lockFrame( Eavesdrop, false, nil );
	Eavesdrop:SetWidth( plugin.width ); 
	Eavesdrop:SetHeight( plugin.height ); 
	EavesDropOptions["NUMLINES"] = floor( (plugin.height - 25) / (EavesDropOptions["LINEHEIGHT"] + 1));
	EavesDropOptions["LINEWIDTH"] = plugin.width - 50;
	EavesDrop:UpdateFrame();
	nUI_Movers:lockFrame( Eavesdrop, true, nil );
end

--[[ The InfoPanel initialisation routine ]]--
plugin.initPanel = function( container, options )
	plugin.container = container;
	plugin.options   = options;
	if options and options.enabled then
		plugin.setEnabled( true );
	end
end

--[[ The InfoPanel resizing routine ]]--
plugin.sizeChanged = function( scale, height, width )
	plugin.scale = scale;
	plugin.height = height;
	plugin.width = width;
	resizeEavesDrop();
end	

--[[ The InfoPanel enabling routine ]]--
plugin.setEnabled = function( enabled )
	if plugin.enabled ~= enabled then
		plugin.enabled = enabled;
		if not enabled then
			disableEavesDrop();
		else
			enableEavesDrop();
		end				
	end			
end

--[[ The InfoPanel selection routine ]]--
plugin.setSelected = function( selected )
	if selected ~= plugin.selected then
		plugin.selected = selected;
		if selected then
		else
		end
	end
end

--[[ Handle the addons Events ]]--
local function onEvent()
	if event == "ADDON_LOADED" and arg1 == addonName then
		if not IsAddOnLoaded( "EavesDrop" ) then 
			LoadAddOn( "EavesDrop" );
		end
		plugin.active = IsAddOnLoaded( "EavesDrop" );
	elseif event == "PLAYER_LOGOUT" then
		if ( plugin.enabled ) then plugin.setEnabled(false); end
	end	
end

--[[ Set Up the Event Script ]]--
plugin:SetScript( "OnEvent", onEvent );
plugin:RegisterEvent( "ADDON_LOADED" );
plugin:RegisterEvent( "PLAYER_LOGOUT" );
